var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GetBridFromChainException } from "./errors";
import { abortOnError, singleEndpoint, tryNextOnError, } from "./failoverStrategies";
import { Method } from "./enums";
import { defaultFailoverConfig } from "../blockchainClient/utils";
import { FailoverStrategy } from "../blockchainClient/enums";
export function getBlockchainRidFromIid(endpointPool, chainId, failOverConfig = defaultFailoverConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const config = {
            endpointPool,
            blockchainRid: undefined,
            pollingInterval: 500,
            failoverStrategy: failOverConfig.strategy || defaultFailoverConfig.strategy,
            attemptsPerEndpoint: failOverConfig.attemptsPerEndpoint ||
                defaultFailoverConfig.attemptsPerEndpoint,
            attemptInterval: failOverConfig.attemptInterval || defaultFailoverConfig.attemptInterval,
        };
        const { error, statusCode, rspBody } = yield requestWithRetry(Method.GET, `/brid/iid_${chainId}`, config);
        if (error) {
            throw new GetBridFromChainException(chainId, error.message);
        }
        else if (statusCode !== 200) {
            throw new GetBridFromChainException(chainId, rspBody);
        }
        return rspBody;
    });
}
export function requestWithRetry(method, path, config, postObject) {
    return __awaiter(this, void 0, void 0, function* () {
        let response;
        switch (config.failoverStrategy) {
            case FailoverStrategy.AbortOnError:
                response = yield abortOnError({ method, path, config, postObject });
                break;
            case FailoverStrategy.TryNextOnError:
                response = yield tryNextOnError({ method, path, config, postObject });
                break;
            case FailoverStrategy.SingleEndpoint:
                response = yield singleEndpoint({ method, path, config, postObject });
                break;
        }
        return response;
    });
}
export function nextEndpoint(endpointPool) {
    return endpointPool[Math.floor(Math.random() * endpointPool.length)];
}
export const sleep = (ms) => new Promise((r) => setTimeout(r, ms));
export function convertToPrintable(responseObject) {
    if (typeof responseObject === "bigint") {
        return responseObject + "n";
    }
    else if (typeof responseObject === "object") {
        return JSON.stringify(responseObject, (key, value) => typeof value === "bigint" ? value + "n" : value);
    }
    else {
        return responseObject;
    }
}
//# sourceMappingURL=restclientutil.js.map